use strict;

use SkypeAPI::Robot;
use Data::Dumper;



SkypeAPI::Robot->new->run();



